# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEnterpriseDatabasesDatabaseResult',
    'GetEnterpriseInstancesInstanceResult',
    'GetEnterpriseLogicDatabasesDatabaseResult',
    'GetEnterpriseProxiesProxyResult',
    'GetEnterpriseProxyAccessesAccessResult',
    'GetEnterpriseUsersUserResult',
    'GetUserTenantsTenantResult',
]

@pulumi.output_type
class GetEnterpriseDatabasesDatabaseResult(dict):
    def __init__(__self__, *,
                 catalog_name: str,
                 database_id: str,
                 db_type: str,
                 dba_id: str,
                 dba_name: str,
                 encoding: str,
                 env_type: str,
                 host: str,
                 id: str,
                 instance_id: str,
                 owner_id_lists: Sequence[str],
                 owner_name_lists: Sequence[str],
                 port: int,
                 schema_name: str,
                 search_name: str,
                 sid: str,
                 state: str):
        """
        :param str catalog_name: The name of the Database Directory.> PG Series databases will display the database name.
        :param str database_id: The ID of the physical library.
        :param str db_type: Database type.
        :param str dba_id: The DBA user ID of the target database.
        :param str dba_name: The DBA nickname of the target Library.
        :param str encoding: Database encoding.
        :param str env_type: The environment type of the database.
        :param str host: The database connection address.
        :param str id: The Database ID, same value as `database_id`.
        :param str instance_id: The instance ID of the target database.
        :param Sequence[str] owner_id_lists: Library Owner User ID list.
        :param Sequence[str] owner_name_lists: Library Owner nickname list.
        :param int port: The connection port of the database.
        :param str schema_name: The name of the database.> PG Series databases will display schema names.
        :param str search_name: Library search name.
        :param str sid: Database SID.> only Oracle Database Display.
        :param str state: Library status, value description:-**NORMAL**: NORMAL-**DISABLE**: Disabled-**OFFLINE**: OFFLINE-**NOT_EXIST**: does not exist
        """
        pulumi.set(__self__, "catalog_name", catalog_name)
        pulumi.set(__self__, "database_id", database_id)
        pulumi.set(__self__, "db_type", db_type)
        pulumi.set(__self__, "dba_id", dba_id)
        pulumi.set(__self__, "dba_name", dba_name)
        pulumi.set(__self__, "encoding", encoding)
        pulumi.set(__self__, "env_type", env_type)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "owner_id_lists", owner_id_lists)
        pulumi.set(__self__, "owner_name_lists", owner_name_lists)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "schema_name", schema_name)
        pulumi.set(__self__, "search_name", search_name)
        pulumi.set(__self__, "sid", sid)
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> str:
        """
        The name of the Database Directory.> PG Series databases will display the database name.
        """
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> str:
        """
        The ID of the physical library.
        """
        return pulumi.get(self, "database_id")

    @property
    @pulumi.getter(name="dbType")
    def db_type(self) -> str:
        """
        Database type.
        """
        return pulumi.get(self, "db_type")

    @property
    @pulumi.getter(name="dbaId")
    def dba_id(self) -> str:
        """
        The DBA user ID of the target database.
        """
        return pulumi.get(self, "dba_id")

    @property
    @pulumi.getter(name="dbaName")
    def dba_name(self) -> str:
        """
        The DBA nickname of the target Library.
        """
        return pulumi.get(self, "dba_name")

    @property
    @pulumi.getter
    def encoding(self) -> str:
        """
        Database encoding.
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> str:
        """
        The environment type of the database.
        """
        return pulumi.get(self, "env_type")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        The database connection address.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The Database ID, same value as `database_id`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The instance ID of the target database.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ownerIdLists")
    def owner_id_lists(self) -> Sequence[str]:
        """
        Library Owner User ID list.
        """
        return pulumi.get(self, "owner_id_lists")

    @property
    @pulumi.getter(name="ownerNameLists")
    def owner_name_lists(self) -> Sequence[str]:
        """
        Library Owner nickname list.
        """
        return pulumi.get(self, "owner_name_lists")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        The connection port of the database.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> str:
        """
        The name of the database.> PG Series databases will display schema names.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="searchName")
    def search_name(self) -> str:
        """
        Library search name.
        """
        return pulumi.get(self, "search_name")

    @property
    @pulumi.getter
    def sid(self) -> str:
        """
        Database SID.> only Oracle Database Display.
        """
        return pulumi.get(self, "sid")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        Library status, value description:-**NORMAL**: NORMAL-**DISABLE**: Disabled-**OFFLINE**: OFFLINE-**NOT_EXIST**: does not exist
        """
        return pulumi.get(self, "state")


@pulumi.output_type
class GetEnterpriseInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 data_link_name: str,
                 database_password: str,
                 database_user: str,
                 dba_id: str,
                 dba_nick_name: str,
                 ddl_online: int,
                 ecs_instance_id: str,
                 ecs_region: str,
                 env_type: str,
                 export_timeout: int,
                 host: str,
                 id: str,
                 instance_alias: str,
                 instance_id: str,
                 instance_name: str,
                 instance_source: str,
                 instance_type: str,
                 port: int,
                 query_timeout: int,
                 safe_rule_id: str,
                 sid: str,
                 status: str,
                 use_dsql: int,
                 vpc_id: str):
        """
        :param str data_link_name: The name of the data link for the database instance.
        :param str database_password: The logon password of the database instance.
        :param str database_user: The logon username of the database instance.
        :param str dba_id: The ID of the database administrator (DBA) of the database instance.
        :param str dba_nick_name: The nickname of the DBA.
        :param int ddl_online: Indicates whether the online data description language (DDL) service was enabled for the database instance.
        :param str ecs_instance_id: The ID of the Elastic Compute Service (ECS) instance to which the database instance belongs.
        :param str ecs_region: The region where the database instance resides.
        :param str env_type: The type of the environment to which the database instance belongs.
        :param int export_timeout: The timeout period for exporting the database instance.
        :param str host: The endpoint of the database instance.
        :param str instance_alias: The alias of the database instance.
        :param str instance_id: The ID of the database instance.
        :param str instance_source: The source of the database instance.
        :param str instance_type: The ID of the database instance.
        :param int port: The connection port of the database instance.
        :param int query_timeout: The timeout period for querying the database instance.
        :param str safe_rule_id: The ID of the security rule for the database instance.
        :param str sid: The system ID (SID) of the database instance.
        :param str status: Filter the results by status of the DMS Enterprise Instances. Valid values: `NORMAL`, `UNAVAILABLE`, `UNKNOWN`, `DELETED`, `DISABLE`.
        :param int use_dsql: Indicates whether cross-database query was enabled for the database instance.
        :param str vpc_id: The ID of the Virtual Private Cloud (VPC) to which the database instance belongs.
        """
        pulumi.set(__self__, "data_link_name", data_link_name)
        pulumi.set(__self__, "database_password", database_password)
        pulumi.set(__self__, "database_user", database_user)
        pulumi.set(__self__, "dba_id", dba_id)
        pulumi.set(__self__, "dba_nick_name", dba_nick_name)
        pulumi.set(__self__, "ddl_online", ddl_online)
        pulumi.set(__self__, "ecs_instance_id", ecs_instance_id)
        pulumi.set(__self__, "ecs_region", ecs_region)
        pulumi.set(__self__, "env_type", env_type)
        pulumi.set(__self__, "export_timeout", export_timeout)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_alias", instance_alias)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_source", instance_source)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "query_timeout", query_timeout)
        pulumi.set(__self__, "safe_rule_id", safe_rule_id)
        pulumi.set(__self__, "sid", sid)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "use_dsql", use_dsql)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="dataLinkName")
    def data_link_name(self) -> str:
        """
        The name of the data link for the database instance.
        """
        return pulumi.get(self, "data_link_name")

    @property
    @pulumi.getter(name="databasePassword")
    def database_password(self) -> str:
        """
        The logon password of the database instance.
        """
        return pulumi.get(self, "database_password")

    @property
    @pulumi.getter(name="databaseUser")
    def database_user(self) -> str:
        """
        The logon username of the database instance.
        """
        return pulumi.get(self, "database_user")

    @property
    @pulumi.getter(name="dbaId")
    def dba_id(self) -> str:
        """
        The ID of the database administrator (DBA) of the database instance.
        """
        return pulumi.get(self, "dba_id")

    @property
    @pulumi.getter(name="dbaNickName")
    def dba_nick_name(self) -> str:
        """
        The nickname of the DBA.
        """
        return pulumi.get(self, "dba_nick_name")

    @property
    @pulumi.getter(name="ddlOnline")
    def ddl_online(self) -> int:
        """
        Indicates whether the online data description language (DDL) service was enabled for the database instance.
        """
        return pulumi.get(self, "ddl_online")

    @property
    @pulumi.getter(name="ecsInstanceId")
    def ecs_instance_id(self) -> str:
        """
        The ID of the Elastic Compute Service (ECS) instance to which the database instance belongs.
        """
        return pulumi.get(self, "ecs_instance_id")

    @property
    @pulumi.getter(name="ecsRegion")
    def ecs_region(self) -> str:
        """
        The region where the database instance resides.
        """
        return pulumi.get(self, "ecs_region")

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> str:
        """
        The type of the environment to which the database instance belongs.
        """
        return pulumi.get(self, "env_type")

    @property
    @pulumi.getter(name="exportTimeout")
    def export_timeout(self) -> int:
        """
        The timeout period for exporting the database instance.
        """
        return pulumi.get(self, "export_timeout")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        The endpoint of the database instance.
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceAlias")
    def instance_alias(self) -> str:
        """
        The alias of the database instance.
        """
        return pulumi.get(self, "instance_alias")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> str:
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceSource")
    def instance_source(self) -> str:
        """
        The source of the database instance.
        """
        return pulumi.get(self, "instance_source")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        The connection port of the database instance.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="queryTimeout")
    def query_timeout(self) -> int:
        """
        The timeout period for querying the database instance.
        """
        return pulumi.get(self, "query_timeout")

    @property
    @pulumi.getter(name="safeRuleId")
    def safe_rule_id(self) -> str:
        """
        The ID of the security rule for the database instance.
        """
        return pulumi.get(self, "safe_rule_id")

    @property
    @pulumi.getter
    def sid(self) -> str:
        """
        The system ID (SID) of the database instance.
        """
        return pulumi.get(self, "sid")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Filter the results by status of the DMS Enterprise Instances. Valid values: `NORMAL`, `UNAVAILABLE`, `UNKNOWN`, `DELETED`, `DISABLE`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="useDsql")
    def use_dsql(self) -> int:
        """
        Indicates whether cross-database query was enabled for the database instance.
        """
        return pulumi.get(self, "use_dsql")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the Virtual Private Cloud (VPC) to which the database instance belongs.
        """
        return pulumi.get(self, "vpc_id")


@pulumi.output_type
class GetEnterpriseLogicDatabasesDatabaseResult(dict):
    def __init__(__self__, *,
                 alias: str,
                 database_ids: Sequence[str],
                 db_type: str,
                 env_type: str,
                 id: str,
                 logic: bool,
                 logic_database_id: str,
                 owner_id_lists: Sequence[str],
                 owner_name_lists: Sequence[str],
                 schema_name: str,
                 search_name: str):
        """
        :param str alias: Logical Library alias.
        :param Sequence[str] database_ids: Sub-Database ID.
        :param str db_type: Database type.
        :param str env_type: Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        :param str id: Logic Database ID.
        :param bool logic: Whether it is a logical Library, the return value is true.
        :param str logic_database_id: The ID of the logical Library.
        :param Sequence[str] owner_id_lists: The user ID list of the logical library Owner.
        :param Sequence[str] owner_name_lists: The nickname list of the logical library Owner.
        :param str schema_name: Logical Library name.
        :param str search_name: Logical library search name.
        """
        pulumi.set(__self__, "alias", alias)
        pulumi.set(__self__, "database_ids", database_ids)
        pulumi.set(__self__, "db_type", db_type)
        pulumi.set(__self__, "env_type", env_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "logic", logic)
        pulumi.set(__self__, "logic_database_id", logic_database_id)
        pulumi.set(__self__, "owner_id_lists", owner_id_lists)
        pulumi.set(__self__, "owner_name_lists", owner_name_lists)
        pulumi.set(__self__, "schema_name", schema_name)
        pulumi.set(__self__, "search_name", search_name)

    @property
    @pulumi.getter
    def alias(self) -> str:
        """
        Logical Library alias.
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="databaseIds")
    def database_ids(self) -> Sequence[str]:
        """
        Sub-Database ID.
        """
        return pulumi.get(self, "database_ids")

    @property
    @pulumi.getter(name="dbType")
    def db_type(self) -> str:
        """
        Database type.
        """
        return pulumi.get(self, "db_type")

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> str:
        """
        Environment type, return value is as follows:-product: production environment-dev: development environment-pre: Advance Environment-test: test environment-sit:SIT environment-uat:UAT environment-pet: Pressure measurement environment-stag:STAG environment
        """
        return pulumi.get(self, "env_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Logic Database ID.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def logic(self) -> bool:
        """
        Whether it is a logical Library, the return value is true.
        """
        return pulumi.get(self, "logic")

    @property
    @pulumi.getter(name="logicDatabaseId")
    def logic_database_id(self) -> str:
        """
        The ID of the logical Library.
        """
        return pulumi.get(self, "logic_database_id")

    @property
    @pulumi.getter(name="ownerIdLists")
    def owner_id_lists(self) -> Sequence[str]:
        """
        The user ID list of the logical library Owner.
        """
        return pulumi.get(self, "owner_id_lists")

    @property
    @pulumi.getter(name="ownerNameLists")
    def owner_name_lists(self) -> Sequence[str]:
        """
        The nickname list of the logical library Owner.
        """
        return pulumi.get(self, "owner_name_lists")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> str:
        """
        Logical Library name.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="searchName")
    def search_name(self) -> str:
        """
        Logical library search name.
        """
        return pulumi.get(self, "search_name")


@pulumi.output_type
class GetEnterpriseProxiesProxyResult(dict):
    def __init__(__self__, *,
                 creator_id: str,
                 creator_name: str,
                 https_port: int,
                 id: str,
                 instance_id: str,
                 private_enable: bool,
                 private_host: str,
                 protocol_port: int,
                 protocol_type: str,
                 proxy_id: str,
                 public_enable: bool,
                 public_host: str):
        """
        :param str creator_id: The ID of the user who enabled the secure access proxy feature.
        :param str creator_name: The nickname of the user who enabled the secure access proxy feature.
        :param int https_port: The port that was used by HTTPS clients to connect to the database instance.
        :param str id: The ID of the Proxy.
        :param str instance_id: The ID of the database instance.
        :param bool private_enable: Indicates whether the internal endpoint is enabled. Default value: true.
        :param str private_host: The internal endpoint.
        :param int protocol_port: Database protocol connection port number.
        :param str protocol_type: Database protocol type, for example, MYSQL.
        :param str proxy_id: The ID of the secure access proxy.
        :param bool public_enable: Indicates whether the public endpoint is enabled.
        :param str public_host: The public endpoint. A public endpoint is returned no matter whether the public endpoint is enabled or disabled. **Note:** When the public network address is in the **true** state, the returned public network address is a valid address with DNS resolution capability. When the public address is in the **false** state, the returned Public address is an invalid address without DNS resolution.
        """
        pulumi.set(__self__, "creator_id", creator_id)
        pulumi.set(__self__, "creator_name", creator_name)
        pulumi.set(__self__, "https_port", https_port)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "private_enable", private_enable)
        pulumi.set(__self__, "private_host", private_host)
        pulumi.set(__self__, "protocol_port", protocol_port)
        pulumi.set(__self__, "protocol_type", protocol_type)
        pulumi.set(__self__, "proxy_id", proxy_id)
        pulumi.set(__self__, "public_enable", public_enable)
        pulumi.set(__self__, "public_host", public_host)

    @property
    @pulumi.getter(name="creatorId")
    def creator_id(self) -> str:
        """
        The ID of the user who enabled the secure access proxy feature.
        """
        return pulumi.get(self, "creator_id")

    @property
    @pulumi.getter(name="creatorName")
    def creator_name(self) -> str:
        """
        The nickname of the user who enabled the secure access proxy feature.
        """
        return pulumi.get(self, "creator_name")

    @property
    @pulumi.getter(name="httpsPort")
    def https_port(self) -> int:
        """
        The port that was used by HTTPS clients to connect to the database instance.
        """
        return pulumi.get(self, "https_port")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Proxy.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="privateEnable")
    def private_enable(self) -> bool:
        """
        Indicates whether the internal endpoint is enabled. Default value: true.
        """
        return pulumi.get(self, "private_enable")

    @property
    @pulumi.getter(name="privateHost")
    def private_host(self) -> str:
        """
        The internal endpoint.
        """
        return pulumi.get(self, "private_host")

    @property
    @pulumi.getter(name="protocolPort")
    def protocol_port(self) -> int:
        """
        Database protocol connection port number.
        """
        return pulumi.get(self, "protocol_port")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> str:
        """
        Database protocol type, for example, MYSQL.
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> str:
        """
        The ID of the secure access proxy.
        """
        return pulumi.get(self, "proxy_id")

    @property
    @pulumi.getter(name="publicEnable")
    def public_enable(self) -> bool:
        """
        Indicates whether the public endpoint is enabled.
        """
        return pulumi.get(self, "public_enable")

    @property
    @pulumi.getter(name="publicHost")
    def public_host(self) -> str:
        """
        The public endpoint. A public endpoint is returned no matter whether the public endpoint is enabled or disabled. **Note:** When the public network address is in the **true** state, the returned public network address is a valid address with DNS resolution capability. When the public address is in the **false** state, the returned Public address is an invalid address without DNS resolution.
        """
        return pulumi.get(self, "public_host")


@pulumi.output_type
class GetEnterpriseProxyAccessesAccessResult(dict):
    def __init__(__self__, *,
                 access_id: str,
                 access_secret: str,
                 create_time: str,
                 id: str,
                 indep_account: str,
                 instance_id: str,
                 origin_info: str,
                 proxy_access_id: str,
                 proxy_id: str,
                 user_id: str,
                 user_name: str,
                 user_uid: str):
        """
        :param str access_id: The authorized account of the security agent.
        :param str create_time: The authorization time of the security access agent permission.
        :param str id: Security Protection authorization ID.
        :param str indep_account: Database account.
        :param str instance_id: The ID of the instance.
        :param str origin_info: The source information of the security access agent permission is enabled, and the return value is as follows:**Owner Authorization**: The UID of the owner in parentheses.**Work Order Authorization**: The ticket number in parentheses is the number of the user to apply for permission.
        :param str proxy_access_id: Security Protection authorization ID. After the target user is authorized by the security protection agent, the system automatically generates a security protection authorization ID, which is globally unique.
        :param str proxy_id: The ID of the security agent.
        :param str user_id: The user ID.
        :param str user_name: User nickname.
        :param str user_uid: User UID.
        """
        pulumi.set(__self__, "access_id", access_id)
        pulumi.set(__self__, "access_secret", access_secret)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "indep_account", indep_account)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "origin_info", origin_info)
        pulumi.set(__self__, "proxy_access_id", proxy_access_id)
        pulumi.set(__self__, "proxy_id", proxy_id)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)
        pulumi.set(__self__, "user_uid", user_uid)

    @property
    @pulumi.getter(name="accessId")
    def access_id(self) -> str:
        """
        The authorized account of the security agent.
        """
        return pulumi.get(self, "access_id")

    @property
    @pulumi.getter(name="accessSecret")
    def access_secret(self) -> str:
        return pulumi.get(self, "access_secret")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The authorization time of the security access agent permission.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Security Protection authorization ID.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="indepAccount")
    def indep_account(self) -> str:
        """
        Database account.
        """
        return pulumi.get(self, "indep_account")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="originInfo")
    def origin_info(self) -> str:
        """
        The source information of the security access agent permission is enabled, and the return value is as follows:**Owner Authorization**: The UID of the owner in parentheses.**Work Order Authorization**: The ticket number in parentheses is the number of the user to apply for permission.
        """
        return pulumi.get(self, "origin_info")

    @property
    @pulumi.getter(name="proxyAccessId")
    def proxy_access_id(self) -> str:
        """
        Security Protection authorization ID. After the target user is authorized by the security protection agent, the system automatically generates a security protection authorization ID, which is globally unique.
        """
        return pulumi.get(self, "proxy_access_id")

    @property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> str:
        """
        The ID of the security agent.
        """
        return pulumi.get(self, "proxy_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The user ID.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> str:
        """
        User nickname.
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userUid")
    def user_uid(self) -> str:
        """
        User UID.
        """
        return pulumi.get(self, "user_uid")


@pulumi.output_type
class GetEnterpriseUsersUserResult(dict):
    def __init__(__self__, *,
                 id: str,
                 mobile: str,
                 nick_name: str,
                 parent_uid: int,
                 role_ids: Sequence[int],
                 role_names: Sequence[str],
                 status: str,
                 uid: str,
                 user_id: str,
                 user_name: str):
        """
        :param str id: The Alibaba Cloud unique ID (UID) of the user.
        :param str mobile: The DingTalk number or mobile number of the user.
        :param str nick_name: The nickname of the user.
        :param int parent_uid: The Alibaba Cloud unique ID (UID) of the parent account if the user corresponds to a Resource Access Management (RAM) user.
        :param Sequence[int] role_ids: The list ids of the role that the user plays.
        :param Sequence[str] role_names: The list names of the role that he user plays.
        :param str status: The status of the user.
        :param str user_id: The ID of the user.
        :param str user_name: The nickname of the user.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mobile", mobile)
        pulumi.set(__self__, "nick_name", nick_name)
        pulumi.set(__self__, "parent_uid", parent_uid)
        pulumi.set(__self__, "role_ids", role_ids)
        pulumi.set(__self__, "role_names", role_names)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "uid", uid)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The Alibaba Cloud unique ID (UID) of the user.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def mobile(self) -> str:
        """
        The DingTalk number or mobile number of the user.
        """
        return pulumi.get(self, "mobile")

    @property
    @pulumi.getter(name="nickName")
    def nick_name(self) -> str:
        """
        The nickname of the user.
        """
        return pulumi.get(self, "nick_name")

    @property
    @pulumi.getter(name="parentUid")
    def parent_uid(self) -> int:
        """
        The Alibaba Cloud unique ID (UID) of the parent account if the user corresponds to a Resource Access Management (RAM) user.
        """
        return pulumi.get(self, "parent_uid")

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Sequence[int]:
        """
        The list ids of the role that the user plays.
        """
        return pulumi.get(self, "role_ids")

    @property
    @pulumi.getter(name="roleNames")
    def role_names(self) -> Sequence[str]:
        """
        The list names of the role that he user plays.
        """
        return pulumi.get(self, "role_names")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the user.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def uid(self) -> str:
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> str:
        """
        The nickname of the user.
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetUserTenantsTenantResult(dict):
    def __init__(__self__, *,
                 id: str,
                 status: str,
                 tenant_name: str,
                 tid: str):
        """
        :param str id: The user tenant id.
        :param str status: The status of the user tenant.
        :param str tenant_name: The name of the user tenant.
        :param str tid: The user tenant id. Same as id.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "tenant_name", tenant_name)
        pulumi.set(__self__, "tid", tid)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The user tenant id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the user tenant.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> str:
        """
        The name of the user tenant.
        """
        return pulumi.get(self, "tenant_name")

    @property
    @pulumi.getter
    def tid(self) -> str:
        """
        The user tenant id. Same as id.
        """
        return pulumi.get(self, "tid")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiDestinationArgs', 'ApiDestination']

@pulumi.input_type
class ApiDestinationArgs:
    def __init__(__self__, *,
                 api_destination_name: pulumi.Input[str],
                 connection_name: pulumi.Input[str],
                 http_api_parameters: pulumi.Input['ApiDestinationHttpApiParametersArgs'],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ApiDestination resource.
        :param pulumi.Input[str] api_destination_name: The name of the API destination.
        :param pulumi.Input[str] connection_name: The name of the connection.
        :param pulumi.Input['ApiDestinationHttpApiParametersArgs'] http_api_parameters: The parameters that are configured for the API destination. See `http_api_parameters` below.
        :param pulumi.Input[str] description: The description of the API destination.
        """
        pulumi.set(__self__, "api_destination_name", api_destination_name)
        pulumi.set(__self__, "connection_name", connection_name)
        pulumi.set(__self__, "http_api_parameters", http_api_parameters)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="apiDestinationName")
    def api_destination_name(self) -> pulumi.Input[str]:
        """
        The name of the API destination.
        """
        return pulumi.get(self, "api_destination_name")

    @api_destination_name.setter
    def api_destination_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "api_destination_name", value)

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> pulumi.Input[str]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "connection_name")

    @connection_name.setter
    def connection_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_name", value)

    @property
    @pulumi.getter(name="httpApiParameters")
    def http_api_parameters(self) -> pulumi.Input['ApiDestinationHttpApiParametersArgs']:
        """
        The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        return pulumi.get(self, "http_api_parameters")

    @http_api_parameters.setter
    def http_api_parameters(self, value: pulumi.Input['ApiDestinationHttpApiParametersArgs']):
        pulumi.set(self, "http_api_parameters", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API destination.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ApiDestinationState:
    def __init__(__self__, *,
                 api_destination_name: Optional[pulumi.Input[str]] = None,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 http_api_parameters: Optional[pulumi.Input['ApiDestinationHttpApiParametersArgs']] = None):
        """
        Input properties used for looking up and filtering ApiDestination resources.
        :param pulumi.Input[str] api_destination_name: The name of the API destination.
        :param pulumi.Input[str] connection_name: The name of the connection.
        :param pulumi.Input[int] create_time: The creation time of the Api Destination.
        :param pulumi.Input[str] description: The description of the API destination.
        :param pulumi.Input['ApiDestinationHttpApiParametersArgs'] http_api_parameters: The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        if api_destination_name is not None:
            pulumi.set(__self__, "api_destination_name", api_destination_name)
        if connection_name is not None:
            pulumi.set(__self__, "connection_name", connection_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if http_api_parameters is not None:
            pulumi.set(__self__, "http_api_parameters", http_api_parameters)

    @property
    @pulumi.getter(name="apiDestinationName")
    def api_destination_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the API destination.
        """
        return pulumi.get(self, "api_destination_name")

    @api_destination_name.setter
    def api_destination_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_destination_name", value)

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "connection_name")

    @connection_name.setter
    def connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        The creation time of the Api Destination.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API destination.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="httpApiParameters")
    def http_api_parameters(self) -> Optional[pulumi.Input['ApiDestinationHttpApiParametersArgs']]:
        """
        The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        return pulumi.get(self, "http_api_parameters")

    @http_api_parameters.setter
    def http_api_parameters(self, value: Optional[pulumi.Input['ApiDestinationHttpApiParametersArgs']]):
        pulumi.set(self, "http_api_parameters", value)


class ApiDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_destination_name: Optional[pulumi.Input[str]] = None,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 http_api_parameters: Optional[pulumi.Input[Union['ApiDestinationHttpApiParametersArgs', 'ApiDestinationHttpApiParametersArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Event Bridge Api Destination resource.

        For information about Event Bridge Api Destination and how to use it, see [What is Api Destination](https://www.alibabacloud.com/help/en/eventbridge/latest/api-eventbridge-2020-04-01-createapidestination).

        > **NOTE:** Available since v1.211.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        region = config.get("region")
        if region is None:
            region = "cn-chengdu"
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eventbridge.Connection("default",
            connection_name=name,
            network_parameters={
                "network_type": "PublicNetwork",
            })
        default_api_destination = alicloud.eventbridge.ApiDestination("default",
            connection_name=default.connection_name,
            api_destination_name=name,
            description="test-api-destination-connection",
            http_api_parameters={
                "endpoint": "http://127.0.0.1:8001",
                "method": "POST",
            })
        ```

        ## Import

        Event Bridge Api Destination can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eventbridge/apiDestination:ApiDestination example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_destination_name: The name of the API destination.
        :param pulumi.Input[str] connection_name: The name of the connection.
        :param pulumi.Input[str] description: The description of the API destination.
        :param pulumi.Input[Union['ApiDestinationHttpApiParametersArgs', 'ApiDestinationHttpApiParametersArgsDict']] http_api_parameters: The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiDestinationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Event Bridge Api Destination resource.

        For information about Event Bridge Api Destination and how to use it, see [What is Api Destination](https://www.alibabacloud.com/help/en/eventbridge/latest/api-eventbridge-2020-04-01-createapidestination).

        > **NOTE:** Available since v1.211.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        region = config.get("region")
        if region is None:
            region = "cn-chengdu"
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.eventbridge.Connection("default",
            connection_name=name,
            network_parameters={
                "network_type": "PublicNetwork",
            })
        default_api_destination = alicloud.eventbridge.ApiDestination("default",
            connection_name=default.connection_name,
            api_destination_name=name,
            description="test-api-destination-connection",
            http_api_parameters={
                "endpoint": "http://127.0.0.1:8001",
                "method": "POST",
            })
        ```

        ## Import

        Event Bridge Api Destination can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eventbridge/apiDestination:ApiDestination example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ApiDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_destination_name: Optional[pulumi.Input[str]] = None,
                 connection_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 http_api_parameters: Optional[pulumi.Input[Union['ApiDestinationHttpApiParametersArgs', 'ApiDestinationHttpApiParametersArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiDestinationArgs.__new__(ApiDestinationArgs)

            if api_destination_name is None and not opts.urn:
                raise TypeError("Missing required property 'api_destination_name'")
            __props__.__dict__["api_destination_name"] = api_destination_name
            if connection_name is None and not opts.urn:
                raise TypeError("Missing required property 'connection_name'")
            __props__.__dict__["connection_name"] = connection_name
            __props__.__dict__["description"] = description
            if http_api_parameters is None and not opts.urn:
                raise TypeError("Missing required property 'http_api_parameters'")
            __props__.__dict__["http_api_parameters"] = http_api_parameters
            __props__.__dict__["create_time"] = None
        super(ApiDestination, __self__).__init__(
            'alicloud:eventbridge/apiDestination:ApiDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_destination_name: Optional[pulumi.Input[str]] = None,
            connection_name: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            description: Optional[pulumi.Input[str]] = None,
            http_api_parameters: Optional[pulumi.Input[Union['ApiDestinationHttpApiParametersArgs', 'ApiDestinationHttpApiParametersArgsDict']]] = None) -> 'ApiDestination':
        """
        Get an existing ApiDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_destination_name: The name of the API destination.
        :param pulumi.Input[str] connection_name: The name of the connection.
        :param pulumi.Input[int] create_time: The creation time of the Api Destination.
        :param pulumi.Input[str] description: The description of the API destination.
        :param pulumi.Input[Union['ApiDestinationHttpApiParametersArgs', 'ApiDestinationHttpApiParametersArgsDict']] http_api_parameters: The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiDestinationState.__new__(_ApiDestinationState)

        __props__.__dict__["api_destination_name"] = api_destination_name
        __props__.__dict__["connection_name"] = connection_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["http_api_parameters"] = http_api_parameters
        return ApiDestination(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiDestinationName")
    def api_destination_name(self) -> pulumi.Output[str]:
        """
        The name of the API destination.
        """
        return pulumi.get(self, "api_destination_name")

    @property
    @pulumi.getter(name="connectionName")
    def connection_name(self) -> pulumi.Output[str]:
        """
        The name of the connection.
        """
        return pulumi.get(self, "connection_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        The creation time of the Api Destination.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the API destination.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="httpApiParameters")
    def http_api_parameters(self) -> pulumi.Output['outputs.ApiDestinationHttpApiParameters']:
        """
        The parameters that are configured for the API destination. See `http_api_parameters` below.
        """
        return pulumi.get(self, "http_api_parameters")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAppsAppResult',
    'GetProductsProductResult',
]

@pulumi.output_type
class GetAppsAppResult(dict):
    def __init__(__self__, *,
                 app_key: str,
                 app_name: str,
                 bundle_id: str,
                 create_time: str,
                 encoded_icon: str,
                 id: str,
                 industry_id: str,
                 package_name: str,
                 product_id: str,
                 type: str):
        """
        :param str app_key: Application AppKey, which uniquely identifies an application when requested by the interface
        :param str app_name: The Name of the App.
        :param str bundle_id: iOS application ID. Required when creating an iOS app. **NOTE:** Either `bundle_id` or `package_name` must be set.
        :param str create_time: The CreateTime of the App.
        :param str encoded_icon: Base64 string of picture.
        :param str id: The ID of the App.
        :param str industry_id: The Industry ID of the app. For information about Industry and how to use it, MHUB[Industry](https://help.aliyun.com/document_detail/201638.html).
        :param str package_name: Android App package name.  **NOTE:** Either `bundle_id` or `package_name` must be set.
        :param str product_id: The ID of the Product.
        :param str type: The type of the App. Valid values: `Android` and `iOS`.
        """
        pulumi.set(__self__, "app_key", app_key)
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "bundle_id", bundle_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "encoded_icon", encoded_icon)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "industry_id", industry_id)
        pulumi.set(__self__, "package_name", package_name)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="appKey")
    def app_key(self) -> str:
        """
        Application AppKey, which uniquely identifies an application when requested by the interface
        """
        return pulumi.get(self, "app_key")

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> str:
        """
        The Name of the App.
        """
        return pulumi.get(self, "app_name")

    @property
    @pulumi.getter(name="bundleId")
    def bundle_id(self) -> str:
        """
        iOS application ID. Required when creating an iOS app. **NOTE:** Either `bundle_id` or `package_name` must be set.
        """
        return pulumi.get(self, "bundle_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The CreateTime of the App.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="encodedIcon")
    def encoded_icon(self) -> str:
        """
        Base64 string of picture.
        """
        return pulumi.get(self, "encoded_icon")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the App.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="industryId")
    def industry_id(self) -> str:
        """
        The Industry ID of the app. For information about Industry and how to use it, MHUB[Industry](https://help.aliyun.com/document_detail/201638.html).
        """
        return pulumi.get(self, "industry_id")

    @property
    @pulumi.getter(name="packageName")
    def package_name(self) -> str:
        """
        Android App package name.  **NOTE:** Either `bundle_id` or `package_name` must be set.
        """
        return pulumi.get(self, "package_name")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        The ID of the Product.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the App. Valid values: `Android` and `iOS`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetProductsProductResult(dict):
    def __init__(__self__, *,
                 id: str,
                 product_id: str,
                 product_name: str):
        """
        :param str id: The ID of the Product.
        :param str product_id: The ID of the Product.
        :param str product_name: The name of the Product.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_name", product_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Product.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> str:
        """
        The ID of the Product.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> str:
        """
        The name of the Product.
        """
        return pulumi.get(self, "product_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetZoneRecordsResult',
    'AwaitableGetZoneRecordsResult',
    'get_zone_records',
    'get_zone_records_output',
]

@pulumi.output_type
class GetZoneRecordsResult:
    """
    A collection of values returned by getZoneRecords.
    """
    def __init__(__self__, id=None, ids=None, keyword=None, lang=None, output_file=None, records=None, search_mode=None, status=None, tag=None, user_client_ip=None, zone_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if keyword and not isinstance(keyword, str):
            raise TypeError("Expected argument 'keyword' to be a str")
        pulumi.set(__self__, "keyword", keyword)
        if lang and not isinstance(lang, str):
            raise TypeError("Expected argument 'lang' to be a str")
        pulumi.set(__self__, "lang", lang)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if records and not isinstance(records, list):
            raise TypeError("Expected argument 'records' to be a list")
        pulumi.set(__self__, "records", records)
        if search_mode and not isinstance(search_mode, str):
            raise TypeError("Expected argument 'search_mode' to be a str")
        pulumi.set(__self__, "search_mode", search_mode)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        pulumi.set(__self__, "tag", tag)
        if user_client_ip and not isinstance(user_client_ip, str):
            raise TypeError("Expected argument 'user_client_ip' to be a str")
        pulumi.set(__self__, "user_client_ip", user_client_ip)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Private Zone Record IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def keyword(self) -> Optional[str]:
        return pulumi.get(self, "keyword")

    @property
    @pulumi.getter
    def lang(self) -> Optional[str]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def records(self) -> Sequence['outputs.GetZoneRecordsRecordResult']:
        """
        A list of zone records. Each element contains the following attributes:
        """
        return pulumi.get(self, "records")

    @property
    @pulumi.getter(name="searchMode")
    def search_mode(self) -> Optional[str]:
        return pulumi.get(self, "search_mode")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        Status of the Private Zone Record.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tag(self) -> Optional[str]:
        return pulumi.get(self, "tag")

    @property
    @pulumi.getter(name="userClientIp")
    def user_client_ip(self) -> Optional[str]:
        return pulumi.get(self, "user_client_ip")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        return pulumi.get(self, "zone_id")


class AwaitableGetZoneRecordsResult(GetZoneRecordsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetZoneRecordsResult(
            id=self.id,
            ids=self.ids,
            keyword=self.keyword,
            lang=self.lang,
            output_file=self.output_file,
            records=self.records,
            search_mode=self.search_mode,
            status=self.status,
            tag=self.tag,
            user_client_ip=self.user_client_ip,
            zone_id=self.zone_id)


def get_zone_records(ids: Optional[Sequence[str]] = None,
                     keyword: Optional[str] = None,
                     lang: Optional[str] = None,
                     output_file: Optional[str] = None,
                     search_mode: Optional[str] = None,
                     status: Optional[str] = None,
                     tag: Optional[str] = None,
                     user_client_ip: Optional[str] = None,
                     zone_id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetZoneRecordsResult:
    """
    This data source provides Private Zone Records resource information owned by an Alibaba Cloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    records_ds = alicloud.pvtz.get_zone_records(zone_id=basic["id"],
        keyword=foo["value"])
    pulumi.export("firstRecordId", records_ds.records[0].id)
    ```


    :param Sequence[str] ids: A list of Private Zone Record IDs.
    :param str keyword: Keyword for record rr and value.
    :param str lang: User language.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str search_mode: Search mode. Value: 
           - LIKE: fuzzy search.
           - EXACT: precise search. It is not filled in by default.
    :param str status: Resolve record status. Value:
           - ENABLE: enable resolution.
           - DISABLE: pause parsing.
    :param str tag: It is not filled in by default, and queries the current zone resolution records. Fill in "ecs" to query the host name record list under the VPC associated with the current zone.
    :param str user_client_ip: User ip.
    :param str zone_id: ID of the Private Zone.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['keyword'] = keyword
    __args__['lang'] = lang
    __args__['outputFile'] = output_file
    __args__['searchMode'] = search_mode
    __args__['status'] = status
    __args__['tag'] = tag
    __args__['userClientIp'] = user_client_ip
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:pvtz/getZoneRecords:getZoneRecords', __args__, opts=opts, typ=GetZoneRecordsResult).value

    return AwaitableGetZoneRecordsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        keyword=pulumi.get(__ret__, 'keyword'),
        lang=pulumi.get(__ret__, 'lang'),
        output_file=pulumi.get(__ret__, 'output_file'),
        records=pulumi.get(__ret__, 'records'),
        search_mode=pulumi.get(__ret__, 'search_mode'),
        status=pulumi.get(__ret__, 'status'),
        tag=pulumi.get(__ret__, 'tag'),
        user_client_ip=pulumi.get(__ret__, 'user_client_ip'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_zone_records_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            keyword: Optional[pulumi.Input[Optional[str]]] = None,
                            lang: Optional[pulumi.Input[Optional[str]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            search_mode: Optional[pulumi.Input[Optional[str]]] = None,
                            status: Optional[pulumi.Input[Optional[str]]] = None,
                            tag: Optional[pulumi.Input[Optional[str]]] = None,
                            user_client_ip: Optional[pulumi.Input[Optional[str]]] = None,
                            zone_id: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetZoneRecordsResult]:
    """
    This data source provides Private Zone Records resource information owned by an Alibaba Cloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    records_ds = alicloud.pvtz.get_zone_records(zone_id=basic["id"],
        keyword=foo["value"])
    pulumi.export("firstRecordId", records_ds.records[0].id)
    ```


    :param Sequence[str] ids: A list of Private Zone Record IDs.
    :param str keyword: Keyword for record rr and value.
    :param str lang: User language.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str search_mode: Search mode. Value: 
           - LIKE: fuzzy search.
           - EXACT: precise search. It is not filled in by default.
    :param str status: Resolve record status. Value:
           - ENABLE: enable resolution.
           - DISABLE: pause parsing.
    :param str tag: It is not filled in by default, and queries the current zone resolution records. Fill in "ecs" to query the host name record list under the VPC associated with the current zone.
    :param str user_client_ip: User ip.
    :param str zone_id: ID of the Private Zone.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['keyword'] = keyword
    __args__['lang'] = lang
    __args__['outputFile'] = output_file
    __args__['searchMode'] = search_mode
    __args__['status'] = status
    __args__['tag'] = tag
    __args__['userClientIp'] = user_client_ip
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:pvtz/getZoneRecords:getZoneRecords', __args__, opts=opts, typ=GetZoneRecordsResult)
    return __ret__.apply(lambda __response__: GetZoneRecordsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        keyword=pulumi.get(__response__, 'keyword'),
        lang=pulumi.get(__response__, 'lang'),
        output_file=pulumi.get(__response__, 'output_file'),
        records=pulumi.get(__response__, 'records'),
        search_mode=pulumi.get(__response__, 'search_mode'),
        status=pulumi.get(__response__, 'status'),
        tag=pulumi.get(__response__, 'tag'),
        user_client_ip=pulumi.get(__response__, 'user_client_ip'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDataBackupsResult',
    'AwaitableGetDataBackupsResult',
    'get_data_backups',
    'get_data_backups_output',
]

@pulumi.output_type
class GetDataBackupsResult:
    """
    A collection of values returned by getDataBackups.
    """
    def __init__(__self__, backup_mode=None, backups=None, data_backup_id=None, data_type=None, db_instance_id=None, end_time=None, id=None, ids=None, output_file=None, page_number=None, page_size=None, start_time=None, status=None):
        if backup_mode and not isinstance(backup_mode, str):
            raise TypeError("Expected argument 'backup_mode' to be a str")
        pulumi.set(__self__, "backup_mode", backup_mode)
        if backups and not isinstance(backups, list):
            raise TypeError("Expected argument 'backups' to be a list")
        pulumi.set(__self__, "backups", backups)
        if data_backup_id and not isinstance(data_backup_id, str):
            raise TypeError("Expected argument 'data_backup_id' to be a str")
        pulumi.set(__self__, "data_backup_id", data_backup_id)
        if data_type and not isinstance(data_type, str):
            raise TypeError("Expected argument 'data_type' to be a str")
        pulumi.set(__self__, "data_type", data_type)
        if db_instance_id and not isinstance(db_instance_id, str):
            raise TypeError("Expected argument 'db_instance_id' to be a str")
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        if end_time and not isinstance(end_time, str):
            raise TypeError("Expected argument 'end_time' to be a str")
        pulumi.set(__self__, "end_time", end_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if start_time and not isinstance(start_time, str):
            raise TypeError("Expected argument 'start_time' to be a str")
        pulumi.set(__self__, "start_time", start_time)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="backupMode")
    def backup_mode(self) -> Optional[str]:
        """
        Backup mode.Full Backup Value Description:-**Automated**: The system is automatically backed up.-**Manual**: Manual backup.Recovery point value description:-**Automated**: The recovery point after a full backup.-**Manual**: The recovery point triggered manually by the user.-**Period**: The recovery point triggered periodically because of the backup policy.
        """
        return pulumi.get(self, "backup_mode")

    @property
    @pulumi.getter
    def backups(self) -> Sequence['outputs.GetDataBackupsBackupResult']:
        """
        A list of Data Backup Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "backups")

    @property
    @pulumi.getter(name="dataBackupId")
    def data_backup_id(self) -> Optional[str]:
        return pulumi.get(self, "data_backup_id")

    @property
    @pulumi.getter(name="dataType")
    def data_type(self) -> Optional[str]:
        """
        The backup type. Value Description:-**DATA**: Full backup.-**RESTOREPOI**: Recoverable point.
        """
        return pulumi.get(self, "data_type")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> str:
        """
        The instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[str]:
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Data Backup IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[str]:
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        Backup set status. Value Description:-Success: The backup has been completed.-Failed: Backup Failed.If not, return all.
        """
        return pulumi.get(self, "status")


class AwaitableGetDataBackupsResult(GetDataBackupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataBackupsResult(
            backup_mode=self.backup_mode,
            backups=self.backups,
            data_backup_id=self.data_backup_id,
            data_type=self.data_type,
            db_instance_id=self.db_instance_id,
            end_time=self.end_time,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            start_time=self.start_time,
            status=self.status)


def get_data_backups(backup_mode: Optional[str] = None,
                     data_backup_id: Optional[str] = None,
                     data_type: Optional[str] = None,
                     db_instance_id: Optional[str] = None,
                     end_time: Optional[str] = None,
                     ids: Optional[Sequence[str]] = None,
                     output_file: Optional[str] = None,
                     page_number: Optional[int] = None,
                     page_size: Optional[int] = None,
                     start_time: Optional[str] = None,
                     status: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataBackupsResult:
    """
    This data source provides Gpdb Data Backup available to the user.[What is Data Backup](https://www.alibabacloud.com/help/en/)

    > **NOTE:** Available since v1.231.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.gpdb.get_instances(name_regex="^default-NODELETING$")
    default_get_data_backups = alicloud.gpdb.get_data_backups(db_instance_id=default.ids[0])
    pulumi.export("alicloudGpdbDataBackupExampleId", default_get_data_backups.backups[0].db_instance_id)
    ```


    :param str backup_mode: Backup mode.Full Backup Value Description:-**Automated**: The system is automatically backed up.-**Manual**: Manual backup.Recovery point value description:-**Automated**: The recovery point after a full backup.-**Manual**: The recovery point triggered manually by the user.-**Period**: The recovery point triggered periodically because of the backup policy.
    :param str data_backup_id: The first ID of the resource
    :param str data_type: The backup type. Value Description:-**DATA**: Full backup.-**RESTOREPOI**: Recoverable point.
    :param str db_instance_id: The instance ID.
    :param str end_time: The query end time, which must be greater than the query start time. Format: yyyy-MM-ddTHH:mmZ(UTC time).
    :param Sequence[str] ids: A list of Databackup IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int page_number: Current page number.
    :param int page_size: Number of records per page.
    :param str start_time: The query start time. Format: yyyy-MM-ddTHH:mmZ(UTC time).
    :param str status: Backup set status. Value Description:-Success: The backup has been completed.-Failed: Backup Failed.If not, return all.
    """
    __args__ = dict()
    __args__['backupMode'] = backup_mode
    __args__['dataBackupId'] = data_backup_id
    __args__['dataType'] = data_type
    __args__['dbInstanceId'] = db_instance_id
    __args__['endTime'] = end_time
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['startTime'] = start_time
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:gpdb/getDataBackups:getDataBackups', __args__, opts=opts, typ=GetDataBackupsResult).value

    return AwaitableGetDataBackupsResult(
        backup_mode=pulumi.get(__ret__, 'backup_mode'),
        backups=pulumi.get(__ret__, 'backups'),
        data_backup_id=pulumi.get(__ret__, 'data_backup_id'),
        data_type=pulumi.get(__ret__, 'data_type'),
        db_instance_id=pulumi.get(__ret__, 'db_instance_id'),
        end_time=pulumi.get(__ret__, 'end_time'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        start_time=pulumi.get(__ret__, 'start_time'),
        status=pulumi.get(__ret__, 'status'))
def get_data_backups_output(backup_mode: Optional[pulumi.Input[Optional[str]]] = None,
                            data_backup_id: Optional[pulumi.Input[Optional[str]]] = None,
                            data_type: Optional[pulumi.Input[Optional[str]]] = None,
                            db_instance_id: Optional[pulumi.Input[str]] = None,
                            end_time: Optional[pulumi.Input[Optional[str]]] = None,
                            ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            page_number: Optional[pulumi.Input[Optional[int]]] = None,
                            page_size: Optional[pulumi.Input[Optional[int]]] = None,
                            start_time: Optional[pulumi.Input[Optional[str]]] = None,
                            status: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataBackupsResult]:
    """
    This data source provides Gpdb Data Backup available to the user.[What is Data Backup](https://www.alibabacloud.com/help/en/)

    > **NOTE:** Available since v1.231.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.gpdb.get_instances(name_regex="^default-NODELETING$")
    default_get_data_backups = alicloud.gpdb.get_data_backups(db_instance_id=default.ids[0])
    pulumi.export("alicloudGpdbDataBackupExampleId", default_get_data_backups.backups[0].db_instance_id)
    ```


    :param str backup_mode: Backup mode.Full Backup Value Description:-**Automated**: The system is automatically backed up.-**Manual**: Manual backup.Recovery point value description:-**Automated**: The recovery point after a full backup.-**Manual**: The recovery point triggered manually by the user.-**Period**: The recovery point triggered periodically because of the backup policy.
    :param str data_backup_id: The first ID of the resource
    :param str data_type: The backup type. Value Description:-**DATA**: Full backup.-**RESTOREPOI**: Recoverable point.
    :param str db_instance_id: The instance ID.
    :param str end_time: The query end time, which must be greater than the query start time. Format: yyyy-MM-ddTHH:mmZ(UTC time).
    :param Sequence[str] ids: A list of Databackup IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int page_number: Current page number.
    :param int page_size: Number of records per page.
    :param str start_time: The query start time. Format: yyyy-MM-ddTHH:mmZ(UTC time).
    :param str status: Backup set status. Value Description:-Success: The backup has been completed.-Failed: Backup Failed.If not, return all.
    """
    __args__ = dict()
    __args__['backupMode'] = backup_mode
    __args__['dataBackupId'] = data_backup_id
    __args__['dataType'] = data_type
    __args__['dbInstanceId'] = db_instance_id
    __args__['endTime'] = end_time
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['startTime'] = start_time
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:gpdb/getDataBackups:getDataBackups', __args__, opts=opts, typ=GetDataBackupsResult)
    return __ret__.apply(lambda __response__: GetDataBackupsResult(
        backup_mode=pulumi.get(__response__, 'backup_mode'),
        backups=pulumi.get(__response__, 'backups'),
        data_backup_id=pulumi.get(__response__, 'data_backup_id'),
        data_type=pulumi.get(__response__, 'data_type'),
        db_instance_id=pulumi.get(__response__, 'db_instance_id'),
        end_time=pulumi.get(__response__, 'end_time'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        start_time=pulumi.get(__response__, 'start_time'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPolicyAttachmentsResult',
    'AwaitableGetPolicyAttachmentsResult',
    'get_policy_attachments',
    'get_policy_attachments_output',
]

@pulumi.output_type
class GetPolicyAttachmentsResult:
    """
    A collection of values returned by getPolicyAttachments.
    """
    def __init__(__self__, attachments=None, id=None, ids=None, language=None, output_file=None, policy_name=None, policy_type=None, principal_name=None, principal_type=None, resource_group_id=None):
        if attachments and not isinstance(attachments, list):
            raise TypeError("Expected argument 'attachments' to be a list")
        pulumi.set(__self__, "attachments", attachments)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if language and not isinstance(language, str):
            raise TypeError("Expected argument 'language' to be a str")
        pulumi.set(__self__, "language", language)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policy_name and not isinstance(policy_name, str):
            raise TypeError("Expected argument 'policy_name' to be a str")
        pulumi.set(__self__, "policy_name", policy_name)
        if policy_type and not isinstance(policy_type, str):
            raise TypeError("Expected argument 'policy_type' to be a str")
        pulumi.set(__self__, "policy_type", policy_type)
        if principal_name and not isinstance(principal_name, str):
            raise TypeError("Expected argument 'principal_name' to be a str")
        pulumi.set(__self__, "principal_name", principal_name)
        if principal_type and not isinstance(principal_type, str):
            raise TypeError("Expected argument 'principal_type' to be a str")
        pulumi.set(__self__, "principal_type", principal_type)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)

    @property
    @pulumi.getter
    def attachments(self) -> Sequence['outputs.GetPolicyAttachmentsAttachmentResult']:
        """
        A list of Resource Manager Policy Attachment. Each element contains the following attributes:
        """
        return pulumi.get(self, "attachments")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Resource Manager Policy Attachment IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def language(self) -> Optional[str]:
        return pulumi.get(self, "language")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[str]:
        """
        The name of the policy.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[str]:
        """
        The type of the policy.
        """
        return pulumi.get(self, "policy_type")

    @property
    @pulumi.getter(name="principalName")
    def principal_name(self) -> Optional[str]:
        """
        The name of the object to which the policy is attached.
        """
        return pulumi.get(self, "principal_name")

    @property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> Optional[str]:
        """
        The type of the object to which the policy is attached.
        """
        return pulumi.get(self, "principal_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        """
        The ID of the resource group or the ID of the Alibaba Cloud account to which the resource group belongs.
        """
        return pulumi.get(self, "resource_group_id")


class AwaitableGetPolicyAttachmentsResult(GetPolicyAttachmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyAttachmentsResult(
            attachments=self.attachments,
            id=self.id,
            ids=self.ids,
            language=self.language,
            output_file=self.output_file,
            policy_name=self.policy_name,
            policy_type=self.policy_type,
            principal_name=self.principal_name,
            principal_type=self.principal_type,
            resource_group_id=self.resource_group_id)


def get_policy_attachments(language: Optional[str] = None,
                           output_file: Optional[str] = None,
                           policy_name: Optional[str] = None,
                           policy_type: Optional[str] = None,
                           principal_name: Optional[str] = None,
                           principal_type: Optional[str] = None,
                           resource_group_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyAttachmentsResult:
    """
    This data source provides the Resource Manager Policy Attachments of the current Alibaba Cloud user.

    > **NOTE:**  Available in 1.93.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.resourcemanager.get_policy_attachments()
    pulumi.export("firstAttachmentId", example.attachments[0].id)
    ```


    :param str language: The language that is used to return the description of the system policy. Valid values:`en`: English, `zh-CN`: Chinese, `ja`: Japanese.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str policy_name: The name of the policy. The name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
    :param str policy_type: The type of the policy. Valid values: `Custom` and `System`.
    :param str principal_name: The name of the object to which the policy is attached.
    :param str principal_type: The type of the object to which the policy is attached. If you do not specify this parameter, the system lists all types of objects. Valid values: `IMSUser`: RAM user, `IMSGroup`: RAM user group, `ServiceRole`: RAM role.
    :param str resource_group_id: The ID of the resource group or the ID of the Alibaba Cloud account to which the resource group belongs. If you do not specify this parameter, the system lists all policy attachment records under the current account.
    """
    __args__ = dict()
    __args__['language'] = language
    __args__['outputFile'] = output_file
    __args__['policyName'] = policy_name
    __args__['policyType'] = policy_type
    __args__['principalName'] = principal_name
    __args__['principalType'] = principal_type
    __args__['resourceGroupId'] = resource_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:resourcemanager/getPolicyAttachments:getPolicyAttachments', __args__, opts=opts, typ=GetPolicyAttachmentsResult).value

    return AwaitableGetPolicyAttachmentsResult(
        attachments=pulumi.get(__ret__, 'attachments'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        language=pulumi.get(__ret__, 'language'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policy_name=pulumi.get(__ret__, 'policy_name'),
        policy_type=pulumi.get(__ret__, 'policy_type'),
        principal_name=pulumi.get(__ret__, 'principal_name'),
        principal_type=pulumi.get(__ret__, 'principal_type'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'))
def get_policy_attachments_output(language: Optional[pulumi.Input[Optional[str]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  policy_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  policy_type: Optional[pulumi.Input[Optional[str]]] = None,
                                  principal_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  principal_type: Optional[pulumi.Input[Optional[str]]] = None,
                                  resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPolicyAttachmentsResult]:
    """
    This data source provides the Resource Manager Policy Attachments of the current Alibaba Cloud user.

    > **NOTE:**  Available in 1.93.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.resourcemanager.get_policy_attachments()
    pulumi.export("firstAttachmentId", example.attachments[0].id)
    ```


    :param str language: The language that is used to return the description of the system policy. Valid values:`en`: English, `zh-CN`: Chinese, `ja`: Japanese.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str policy_name: The name of the policy. The name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
    :param str policy_type: The type of the policy. Valid values: `Custom` and `System`.
    :param str principal_name: The name of the object to which the policy is attached.
    :param str principal_type: The type of the object to which the policy is attached. If you do not specify this parameter, the system lists all types of objects. Valid values: `IMSUser`: RAM user, `IMSGroup`: RAM user group, `ServiceRole`: RAM role.
    :param str resource_group_id: The ID of the resource group or the ID of the Alibaba Cloud account to which the resource group belongs. If you do not specify this parameter, the system lists all policy attachment records under the current account.
    """
    __args__ = dict()
    __args__['language'] = language
    __args__['outputFile'] = output_file
    __args__['policyName'] = policy_name
    __args__['policyType'] = policy_type
    __args__['principalName'] = principal_name
    __args__['principalType'] = principal_type
    __args__['resourceGroupId'] = resource_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:resourcemanager/getPolicyAttachments:getPolicyAttachments', __args__, opts=opts, typ=GetPolicyAttachmentsResult)
    return __ret__.apply(lambda __response__: GetPolicyAttachmentsResult(
        attachments=pulumi.get(__response__, 'attachments'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        language=pulumi.get(__response__, 'language'),
        output_file=pulumi.get(__response__, 'output_file'),
        policy_name=pulumi.get(__response__, 'policy_name'),
        policy_type=pulumi.get(__response__, 'policy_type'),
        principal_name=pulumi.get(__response__, 'principal_name'),
        principal_type=pulumi.get(__response__, 'principal_type'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CommonBandwithPackageAttachmentArgs', 'CommonBandwithPackageAttachment']

@pulumi.input_type
class CommonBandwithPackageAttachmentArgs:
    def __init__(__self__, *,
                 bandwidth_package_id: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 bandwidth_package_bandwidth: Optional[pulumi.Input[str]] = None,
                 cancel_common_bandwidth_package_ip_bandwidth: Optional[pulumi.Input[bool]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a CommonBandwithPackageAttachment resource.
        :param pulumi.Input[str] bandwidth_package_id: The ID of the Internet Shared Bandwidth instance.
        :param pulumi.Input[str] instance_id: The ID of the EIP that you want to query.
               
               You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).
               
               > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        :param pulumi.Input[str] bandwidth_package_bandwidth: The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        :param pulumi.Input[bool] cancel_common_bandwidth_package_ip_bandwidth: Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        :param pulumi.Input[str] ip_type: The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        """
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if bandwidth_package_bandwidth is not None:
            pulumi.set(__self__, "bandwidth_package_bandwidth", bandwidth_package_bandwidth)
        if cancel_common_bandwidth_package_ip_bandwidth is not None:
            pulumi.set(__self__, "cancel_common_bandwidth_package_ip_bandwidth", cancel_common_bandwidth_package_ip_bandwidth)
        if ip_type is not None:
            pulumi.set(__self__, "ip_type", ip_type)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> pulumi.Input[str]:
        """
        The ID of the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the EIP that you want to query.

        You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).

        > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="bandwidthPackageBandwidth")
    def bandwidth_package_bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        """
        return pulumi.get(self, "bandwidth_package_bandwidth")

    @bandwidth_package_bandwidth.setter
    def bandwidth_package_bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth_package_bandwidth", value)

    @property
    @pulumi.getter(name="cancelCommonBandwidthPackageIpBandwidth")
    def cancel_common_bandwidth_package_ip_bandwidth(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        """
        return pulumi.get(self, "cancel_common_bandwidth_package_ip_bandwidth")

    @cancel_common_bandwidth_package_ip_bandwidth.setter
    def cancel_common_bandwidth_package_ip_bandwidth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cancel_common_bandwidth_package_ip_bandwidth", value)

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "ip_type")

    @ip_type.setter
    def ip_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_type", value)


@pulumi.input_type
class _CommonBandwithPackageAttachmentState:
    def __init__(__self__, *,
                 bandwidth_package_bandwidth: Optional[pulumi.Input[str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[str]] = None,
                 cancel_common_bandwidth_package_ip_bandwidth: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering CommonBandwithPackageAttachment resources.
        :param pulumi.Input[str] bandwidth_package_bandwidth: The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        :param pulumi.Input[str] bandwidth_package_id: The ID of the Internet Shared Bandwidth instance.
        :param pulumi.Input[bool] cancel_common_bandwidth_package_ip_bandwidth: Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        :param pulumi.Input[str] instance_id: The ID of the EIP that you want to query.
               
               You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).
               
               > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        :param pulumi.Input[str] ip_type: The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        :param pulumi.Input[str] status: The status of the Internet Shared Bandwidth instance.
        """
        if bandwidth_package_bandwidth is not None:
            pulumi.set(__self__, "bandwidth_package_bandwidth", bandwidth_package_bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if cancel_common_bandwidth_package_ip_bandwidth is not None:
            pulumi.set(__self__, "cancel_common_bandwidth_package_ip_bandwidth", cancel_common_bandwidth_package_ip_bandwidth)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ip_type is not None:
            pulumi.set(__self__, "ip_type", ip_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="bandwidthPackageBandwidth")
    def bandwidth_package_bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        """
        return pulumi.get(self, "bandwidth_package_bandwidth")

    @bandwidth_package_bandwidth.setter
    def bandwidth_package_bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth_package_bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="cancelCommonBandwidthPackageIpBandwidth")
    def cancel_common_bandwidth_package_ip_bandwidth(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        """
        return pulumi.get(self, "cancel_common_bandwidth_package_ip_bandwidth")

    @cancel_common_bandwidth_package_ip_bandwidth.setter
    def cancel_common_bandwidth_package_ip_bandwidth(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cancel_common_bandwidth_package_ip_bandwidth", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the EIP that you want to query.

        You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).

        > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "ip_type")

    @ip_type.setter
    def ip_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class CommonBandwithPackageAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_package_bandwidth: Optional[pulumi.Input[str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[str]] = None,
                 cancel_common_bandwidth_package_ip_bandwidth: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.vpc.CommonBandwithPackage("default",
            bandwidth="3",
            internet_charge_type="PayByTraffic")
        default_eip_address = alicloud.ecs.EipAddress("default",
            bandwidth="3",
            internet_charge_type="PayByTraffic")
        default_common_bandwith_package_attachment = alicloud.vpc.CommonBandwithPackageAttachment("default",
            bandwidth_package_id=default.id,
            instance_id=default_eip_address.id,
            bandwidth_package_bandwidth="2",
            ip_type="EIP")
        ```

        ## Import

        CBWP Common Bandwidth Package Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/commonBandwithPackageAttachment:CommonBandwithPackageAttachment example <bandwidth_package_id>:<instance_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bandwidth_package_bandwidth: The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        :param pulumi.Input[str] bandwidth_package_id: The ID of the Internet Shared Bandwidth instance.
        :param pulumi.Input[bool] cancel_common_bandwidth_package_ip_bandwidth: Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        :param pulumi.Input[str] instance_id: The ID of the EIP that you want to query.
               
               You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).
               
               > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        :param pulumi.Input[str] ip_type: The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CommonBandwithPackageAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.vpc.CommonBandwithPackage("default",
            bandwidth="3",
            internet_charge_type="PayByTraffic")
        default_eip_address = alicloud.ecs.EipAddress("default",
            bandwidth="3",
            internet_charge_type="PayByTraffic")
        default_common_bandwith_package_attachment = alicloud.vpc.CommonBandwithPackageAttachment("default",
            bandwidth_package_id=default.id,
            instance_id=default_eip_address.id,
            bandwidth_package_bandwidth="2",
            ip_type="EIP")
        ```

        ## Import

        CBWP Common Bandwidth Package Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/commonBandwithPackageAttachment:CommonBandwithPackageAttachment example <bandwidth_package_id>:<instance_id>
        ```

        :param str resource_name: The name of the resource.
        :param CommonBandwithPackageAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CommonBandwithPackageAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_package_bandwidth: Optional[pulumi.Input[str]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[str]] = None,
                 cancel_common_bandwidth_package_ip_bandwidth: Optional[pulumi.Input[bool]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CommonBandwithPackageAttachmentArgs.__new__(CommonBandwithPackageAttachmentArgs)

            __props__.__dict__["bandwidth_package_bandwidth"] = bandwidth_package_bandwidth
            if bandwidth_package_id is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth_package_id'")
            __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
            __props__.__dict__["cancel_common_bandwidth_package_ip_bandwidth"] = cancel_common_bandwidth_package_ip_bandwidth
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["ip_type"] = ip_type
            __props__.__dict__["status"] = None
        super(CommonBandwithPackageAttachment, __self__).__init__(
            'alicloud:vpc/commonBandwithPackageAttachment:CommonBandwithPackageAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth_package_bandwidth: Optional[pulumi.Input[str]] = None,
            bandwidth_package_id: Optional[pulumi.Input[str]] = None,
            cancel_common_bandwidth_package_ip_bandwidth: Optional[pulumi.Input[bool]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            ip_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'CommonBandwithPackageAttachment':
        """
        Get an existing CommonBandwithPackageAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bandwidth_package_bandwidth: The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        :param pulumi.Input[str] bandwidth_package_id: The ID of the Internet Shared Bandwidth instance.
        :param pulumi.Input[bool] cancel_common_bandwidth_package_ip_bandwidth: Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        :param pulumi.Input[str] instance_id: The ID of the EIP that you want to query.
               
               You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).
               
               > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        :param pulumi.Input[str] ip_type: The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        :param pulumi.Input[str] status: The status of the Internet Shared Bandwidth instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CommonBandwithPackageAttachmentState.__new__(_CommonBandwithPackageAttachmentState)

        __props__.__dict__["bandwidth_package_bandwidth"] = bandwidth_package_bandwidth
        __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
        __props__.__dict__["cancel_common_bandwidth_package_ip_bandwidth"] = cancel_common_bandwidth_package_ip_bandwidth
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ip_type"] = ip_type
        __props__.__dict__["status"] = status
        return CommonBandwithPackageAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bandwidthPackageBandwidth")
    def bandwidth_package_bandwidth(self) -> pulumi.Output[str]:
        """
        The maximum bandwidth for the EIP. This value cannot be larger than the maximum bandwidth of the Internet Shared Bandwidth instance. Unit: Mbit/s.
        """
        return pulumi.get(self, "bandwidth_package_bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> pulumi.Output[str]:
        """
        The ID of the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="cancelCommonBandwidthPackageIpBandwidth")
    def cancel_common_bandwidth_package_ip_bandwidth(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to cancel the maximum bandwidth configuration for the EIP. Default: false.
        """
        return pulumi.get(self, "cancel_common_bandwidth_package_ip_bandwidth")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the EIP that you want to query.

        You can specify up to 50 EIP IDs. Separate multiple IDs with commas (,).

        > **NOTE:**   If both `EipAddress` and `AllocationId` are specified, you can specify up to 50 EIP IDs for `AllocationId`, and specify up to 50 EIPs for `EipAddress`.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of IP address. Set the value to `EIP` to associate EIPs with the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "ip_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the Internet Shared Bandwidth instance.
        """
        return pulumi.get(self, "status")

